﻿init python:
    from copy import copy
    import random
    import time
    random.seed(time.time())
    class burger_client:
        def __init__(self, name, image, order, patience):
            self.name = name
            self.image = image
            self.order = order
            self.patience_init = patience
            self.patience = patience
            self.match = 0
            self.missed = 0
            self.cost = 0
            self.done = False
            self.stat = "waiting"
    class burger_part:
        def __init__(self, name, image, thickness, bottom, cost):
            self.name = name
            self.image = image
            self.thickness = thickness
            self.bottom = bottom
            self.cost = cost
            self.offset = 0
            self.flip = 1
            self.xpos = 0
        def nudge(self):
            renpy.play("burger/put.ogg", "sound")
            self.flip = random.choice([-1,1])
            self.xpos = random.randint(-1,1)
    class burger_class:
        def __init__(self, ingredients, clients):
            self.ingredients = ingredients
            self.current = []
            self.clients = clients
            self.current_client = None
            self.tips = 0
        def put(self, i):
            renpy.play("burger/put.ogg", "sound")
            self.current.append(copy(i))
            self.set_offset(self.current)
            i.nudge()
        def reset(self):
            renpy.play("burger/put.ogg", "sound")
            self.current = []
        def orders_up(self):
            renpy.play("burger/orders_up.ogg", "sound")
            client = self.current_client
            if client:
                client.match, client.miss, client.cost = self.compare(client.order, self.current)
                client.done = True
        def pay(self):
            self.current = []
            pay = round(self.current_client.cost, 2)
            self.tips = round(self.tips + pay, 2)
            msg3(pay)
        def clear(self):
            self.current_client = []

        def set_offset(self, order):
            offset = 0
            for i in order:
                i.offset = (offset - i.bottom)
                offset += i.thickness
        def compare(self, order, burger):
            match_score = 0
            missed_points = 0
            cost = 0
            for a,b in zip(order, burger):
                if a.name == b.name:
                    match_score += 1
                    cost += a.cost
                else:
                    missed_points += 1
            
            return [match_score, missed_points, cost]
        def spawn_client(self):
            if self.current_client:
                if self.current_client.patience > 0:
                    self.current_client.patience -= 1
                    return
                else:
                    self.current_client.done = True
                    return

            image = random.choice(self.clients)
            order = self.make_a_sandwich()
            client = burger_client(image, image, order, random.randint(30,50))
            self.current_client = client
        def make_a_sandwich(self):
            order = [copy(self.ingredients[0])]
            for i in range(random.randint(1,6)):
                layer = copy(random.choice(self.ingredients))
                if not layer.image == "burger_8":
                    order.append(layer)
            order.append(copy(self.ingredients[-1]))
            self.set_offset(order)
            return order
init:
    image burger_1 = Crop((0,0,32,32), "burger/burger.png")
    image burger_2 = Crop((32,0,32,32), "burger/burger.png")
    image burger_3 = Crop((64,0,32,32), "burger/burger.png")
    image burger_4 = Crop((96,0,32,32), "burger/burger.png")
    image burger_5 = Crop((0,32,32,32), "burger/burger.png")
    image burger_6 = Crop((32,32,32,32), "burger/burger.png")
    image burger_7 = Crop((64,32,32,32), "burger/burger.png")
    image burger_8 = Crop((96,32,32,32), "burger/burger.png")

transform burger_client_slide_in:
    alpha 0 xoffset 100
    ease 1 alpha 1 xoffset 0
transform burger_client_slide_out:
    alpha 1 xoffset 0
    pause 1
    ease 1 alpha 0 xoffset -100

screen burger_shop():
    modal True
    default g = burger_class(
        ingredients = [
            burger_part("Bottom bun", "burger_1", 5, 0, .10),
            burger_part("Bacon", "burger_2", 1, 3, .50),
            burger_part("Pickles", "burger_3", 1, 2, .10),
            burger_part("Beef paddy", "burger_4", 4, .10, .75),
            burger_part("Cheese", "burger_5", 1, 4, .25),
            burger_part("Tomato", "burger_6", 2, 2, .10),
            burger_part("Egg", "burger_7", 2, 3, .25),
            burger_part("Top bun", "burger_8", 5, 0, .10),
        ],
        clients = [
            "client_1",
            "client_2",
            "client_3",
            "client_4",
            "client_5",
        ]
    )
    add "burger_bg"
    if g.current_client:
        if g.current_client.done:
            timer 1 action Function(g.pay)
            timer 2 action Function(g.clear)
        fixed fit_first True:
            if g.current_client.done:
                at burger_client_slide_out
            else:
                at burger_client_slide_in
            align .5,1.0
            add g.current_client.image
        
            if not g.current_client.done:
                bar value g.current_client.patience range g.current_client.patience_init xysize 400,20 align .5,.0 yoffset -40
                fixed:
                    fit_first True at zoom(4, True)
                    align 1.0,.0 xanchor 0.0
                    for i in g.current_client.order:
                        button:
                            add i.image yoffset -i.offset xzoom i.flip
    timer 1 repeat True action Function(g.spawn_client)

    add "burger_desk"
    fixed:
        fit_first True at zoom(8, True)
        align .5,.6
        for i in g.current:
            button:
                focus_mask True
                add i.image yoffset -i.offset xzoom i.flip xoffset i.xpos
                action Function(i.nudge)
    
    hbox:
        align .5,.9
        at zoom(4, True)
        for i in g.ingredients:
            button:
                add i.image
                action Function(g.put, i)
    hbox spacing 600:
        align .5,.7
        button:
            add "burger_discard"
            action Function(g.reset)
        button:
            add "burger_orders_up"
            action Function(g.orders_up)
    frame:
        padding 20,20 background "#000b"
        text "Tips: $[g.tips]"
    button:
        align 1.0,1.0 padding 20,20 background "#000b"
        text "Done"
        action Return(g.tips)





label burger_example:
    call screen burger_shop